@@ -248,10 +248,22 @@ enum
 #define CS_SEC_APPDEFINED CS_SEC_APPDEFINED
 	CS_STICKY_BINDS = 9151,
 #define CS_STICKY_BINDS CS_STICKY_BINDS
+	CS_SEC_NETWORKAUTH = 9175,
+#define CS_SEC_NETWORKAUTH CS_SEC_NETWORKAUTH
+	CS_SEC_DELEGATION = 9176,
+#define CS_SEC_DELEGATION CS_SEC_DELEGATION
+	CS_SEC_MUTUALAUTH = 9177,
+#define CS_SEC_MUTUALAUTH CS_SEC_MUTUALAUTH
+	CS_SEC_SERVERPRINCIPAL = 9188,
+#define CS_SEC_SERVERPRINCIPAL CS_SEC_SERVERPRINCIPAL
 	CS_SERVERADDR = 9206,
 #define CS_SERVERADDR CS_SERVERADDR
-	CS_PORT = 9300
+	CS_PORT = 9300,
 #define CS_PORT CS_PORT
+	CS_CLIENTCHARSET = 9301,
+#define CS_CLIENTCHARSET CS_CLIENTCHARSET
+	CS_DATABASE = 9302
+#define CS_DATABASE CS_DATABASE
 };
 
 /* Arbitrary precision math operators */
@@ -265,6 +277,8 @@ enum
 
 enum
 {
+#define CS_TDS_AUTO CS_TDS_AUTO
+	CS_TDS_AUTO = 0,
 	CS_TDS_40 = 7360,
 	CS_TDS_42,
 	CS_TDS_46,
@@ -272,9 +286,13 @@ enum
 	CS_TDS_50,
 	CS_TDS_70,
 	CS_TDS_71,
+#define CS_TDS_71 CS_TDS_71
 	CS_TDS_72,
+#define CS_TDS_72 CS_TDS_72
 	CS_TDS_73,
+#define CS_TDS_73 CS_TDS_73
 	CS_TDS_74,
+#define CS_TDS_74 CS_TDS_74
 };
 
 /* bit mask values used by CS_DATAFMT.status */
@@ -582,6 +600,9 @@ enum
 #define CS_BIGTIME_TYPE     TDS_STATIC_CAST(CS_INT, 36)
 #define CS_UNIQUE_TYPE      TDS_STATIC_CAST(CS_INT, 40)
 
+#define CS_MIN_SYBTYPE CS_CHAR_TYPE
+#define CS_MAX_SYBTYPE CS_UNIQUE_TYPE
+
 #define CS_USER_TYPE        TDS_STATIC_CAST(CS_INT, 100)
 /* cs_dt_info type values */
 enum
@@ -729,7 +750,10 @@ CS_RETCODE cs_ctx_drop(CS_CONTEXT * ctx);
 CS_RETCODE cs_config(CS_CONTEXT * ctx, CS_INT action, CS_INT property, CS_VOID * buffer, CS_INT buflen, CS_INT * outlen);
 CS_RETCODE cs_strbuild(CS_CONTEXT * ctx, CS_CHAR * buffer, CS_INT buflen, CS_INT * resultlen, CS_CHAR * text, CS_INT textlen,
 		       CS_CHAR * formats, CS_INT formatlen, ...);
+#undef cs_dt_crack
 CS_RETCODE cs_dt_crack(CS_CONTEXT * ctx, CS_INT datetype, CS_VOID * dateval, CS_DATEREC * daterec);
+CS_RETCODE cs_dt_crack_v2(CS_CONTEXT * ctx, CS_INT datetype, CS_VOID * dateval, CS_DATEREC * daterec);
+#define cs_dt_crack cs_dt_crack_v2
 CS_RETCODE cs_loc_alloc(CS_CONTEXT * ctx, CS_LOCALE ** locptr);
 CS_RETCODE cs_loc_drop(CS_CONTEXT * ctx, CS_LOCALE * locale);
 CS_RETCODE cs_locale(CS_CONTEXT * ctx, CS_INT action, CS_LOCALE * locale, CS_INT type, CS_VOID * buffer, CS_INT buflen,
